@@ -4,7 +4,8 @@ from io import BytesIO, StringIO
 import polars as pl
 import requests
 
-from cameo_claw.net import requests_get
+from cameo_claw.file import mkdir
+from cameo_claw.net import requests_get, url_to_filename
 
 import warnings
 import pandas as pd
@@ -29,8 +30,7 @@ def requests_get_write(target_directory, url, f_write):
 def bytesio_filename(df, url):
     bytesio = BytesIO()
     df.to_csv(bytesio)
-    filename = os.path.basename(url)
-    filename = filename[:filename.find('.')]
+    filename = url_to_filename(url)
     return bytesio, filename
 
 
