@@ -35,7 +35,7 @@ class ItemUrlFilter(BaseModel):
     sort_column: str = 'localTime'
 
 
-async def it_streaming(i: ItemUrlFilter):
+def it_streaming(i: ItemUrlFilter):
     try:
         yield write_csv_header_to_gz(i)
         for int_progress, bytes1 in it_chunk(
@@ -68,11 +68,10 @@ def streaming_post(i: ItemUrlFilter):
 
 
 @app.get("/api/streaming_get/")
-async def streaming_get(md5_hex):
-    print("🐲modify on server")
+def streaming_get(md5_hex):
     dic = {'content-disposition': f"attachment; filename*=utf-8''all.csv.gz"}
     return StreamingResponse(it_streaming(dic_item_url_filter[md5_hex]), headers=dic)
 
 
-def server(host='0.0.0.0', int_port=20437):
+def server(host='0.0.0.0', int_port=20440):
     uvicorn.run("cameo_claw.streaming:app", host=host, port=int_port, reload=False, debug=False, workers=1)
